@@ -8,7 +8,11 @@
  */
 
 
-#include "../afs/param.h"	/* Should be always first */
+#include <afsconfig.h>
+#include "../afs/param.h"
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/FBSD/osi_sleep.c,v 1.1.1.3 2001/07/14 22:20:03 hartmans Exp $");
+
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
 #include "../afs/afs_stats.h"   /* afs statistics */
