@@ -10,7 +10,11 @@
 /*
  * Implementation of miscellaneous Irix routines.
  */
-#include "../afs/param.h"	/* Should be always first */
+#include <afsconfig.h>
+#include "../afs/param.h"
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/IRIX/osi_misc.c,v 1.1.1.4 2001/07/14 22:19:43 hartmans Exp $");
+
 #ifdef	AFS_SGI62_ENV
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
