@@ -10,9 +10,11 @@
 /*
  * SGI specific vnodeops + other misc interface glue
  */
-#ident "$Revision: 1.1.1.3 $"
+#include <afsconfig.h>
+#include "../afs/param.h"
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/IRIX/osi_vnodeops.c,v 1.1.1.6 2001/07/14 22:19:44 hartmans Exp $");
 
-#include "../afs/param.h"	/* Should be always first */
 #ifdef	AFS_SGI62_ENV
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
