@@ -13,7 +13,11 @@
  * Implements:
  *
  */
-#include "../afs/param.h"	/* Should be always first */
+#include <afsconfig.h>
+#include "../afs/param.h"
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/SOLARIS/osi_inode.c,v 1.1.1.7 2001/07/14 22:19:50 hartmans Exp $");
+
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
 #include "../afs/osi_inode.h"
@@ -28,6 +32,9 @@ extern int (*ufs_iallocp)(), (*ufs_iupdatp)(), (*ufs_igetp)(),
         mutex_exit(&(ip)->i_tlock); \
 }
 
+#define AFS_ITIMES_NOLOCK(ip) \
+	(*ufs_itimes_nolockp)(ip);
+
 getinode(vfsp, dev, inode, ipp, credp,perror)
      struct vfs *vfsp;
      struct AFS_UCRED *credp;
@@ -58,11 +65,11 @@ getinode(vfsp, dev, inode, ipp, credp,perror)
     }
     ufsvfsp = (struct ufsvfs *)vfsp->vfs_data;
 
-#if defined(AFS_SUN57_ENV)
+#ifdef HAVE_VFS_DQRWLOCK
     rw_enter(&ufsvfsp->vfs_dqrwlock, RW_READER);
 #endif
     code = (*ufs_igetp)(vfsp, inode, &ip, credp);
-#if defined(AFS_SUN57_ENV)
+#ifdef HAVE_VFS_DQRWLOCK
     rw_exit(&ufsvfsp->vfs_dqrwlock);
 #endif
 
@@ -166,29 +173,25 @@ afs_syscall_icreate(dev, near_inode, param1, param2, param3, param4, rvp, credp)
 
     ufsvfsp = ip->i_ufsvfs;
     rw_enter(&ip->i_rwlock, RW_WRITER);
-#if defined(AFS_SUN57_ENV)
+#ifdef HAVE_VFS_DQRWLOCK
     rw_enter(&ufsvfsp->vfs_dqrwlock, RW_READER);
 #endif
     rw_enter(&ip->i_contents, RW_WRITER);
     code = (*ufs_iallocp)(ip, near_inode, 0, &newip, credp);
-#if defined(AFS_SUN57_ENV)
+    AFS_ITIMES_NOLOCK(ip);
+    rw_exit(&ip->i_contents);
+#ifdef HAVE_VFS_DQRWLOCK
     rw_exit(&ufsvfsp->vfs_dqrwlock);
 #endif
     rw_exit(&ip->i_rwlock);
-
-    AFS_ITIMES(ip);
-    rw_exit(&ip->i_contents);
     VN_RELE(ITOV(ip));
 
     if (code) {
 	return (code);
     }
     rw_enter(&newip->i_contents, RW_WRITER);
-    mutex_enter(&newip->i_tlock);
     newip->i_flag |= IACC|IUPD|ICHG;
-    mutex_exit(&newip->i_tlock);
-    
-    
+
 #if	defined(AFS_SUN56_ENV)
     newip->i_vicemagic = VICEMAGIC;
 #else
@@ -220,7 +223,7 @@ afs_syscall_icreate(dev, near_inode, param1, param2, param3, param4, rvp, credp)
      */
     if (CrSync)
 	(*ufs_iupdatp)(newip, 1);
-    AFS_ITIMES(newip);
+    AFS_ITIMES_NOLOCK(newip);
     rw_exit(&newip->i_contents);
     VN_RELE(ITOV(newip));
     return (code);
@@ -338,13 +341,11 @@ afs_syscall_iincdec(dev, inode, inode_p1, amount, rvp, credp)
 	    dnlc_remove(ITOV(ip), "a");
 	    CLEAR_VICEMAGIC(ip);
 	}
-	mutex_enter(&ip->i_tlock);
 	ip->i_flag |= ICHG;
-	mutex_exit(&ip->i_tlock);
 	/* We may want to force the inode to the disk in case of crashes, other references, etc. */
 	if (IncSync)
 	    (*ufs_iupdatp)(ip, 1);
-	AFS_ITIMES(ip);
+	AFS_ITIMES_NOLOCK(ip);
 	rw_exit(&ip->i_contents);
 	VN_RELE(ITOV(ip));
     }
