@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#include "../afs/param.h"	/* Should be always first */
+#include <afsconfig.h>
+#include "../afs/param.h"
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/SOLARIS/osi_vnodeops.c,v 1.1.1.6 2001/07/14 22:19:50 hartmans Exp $");
+
 #if	defined(AFS_SUN_ENV) || defined(AFS_SUN5_ENV)
 /*
  * SOLARIS/osi_vnodeops.c
@@ -379,7 +383,11 @@ retry:
 	 * As of 4/98, that shouldn't be possible, but we'll be defensive here
 	 * in case someone tries to relax all the serialization of read and write
 	 * operations with harmless things like stat. */
+#if    defined(AFS_SUN58_ENV)
+        page = page_create_va(vp, toffset, PAGESIZE, PG_WAIT|PG_EXCL, seg, addr);
+#else
 	page = page_create_va(vp, toffset, PAGESIZE, PG_WAIT|PG_EXCL, seg->s_as, addr);
+#endif
 #else
 	page = page_create(vp, toffset, PAGESIZE, PG_WAIT);
 #endif
@@ -537,7 +545,12 @@ int afs_putpage(vp, off, len, flags, cred)
     struct vcache *avc;
     struct page *pages;
     afs_int32 code = 0;
-    afs_int32 tlen, endPos, NPages=0;
+#if    defined(AFS_SUN58_ENV)
+    size_t tlen;
+#else
+    afs_int32 tlen;
+#endif
+    afs_int32 endPos, NPages=0;
 #if	defined(AFS_SUN56_ENV)
     u_offset_t toff = off;
 #else
@@ -551,10 +564,6 @@ int afs_putpage(vp, off, len, flags, cred)
     /*
      * Putpage (ASYNC) is called every sec to flush out dirty vm pages 
      */
-    if (flags == B_ASYNC) {
-	/* XXX For testing only XXX */
-	return (EINVAL);
-    }
     AFS_GLOCK();
     afs_Trace4(afs_iclSetp, CM_TRACE_PAGEOUT, ICL_TYPE_POINTER, (afs_int32) vp,
 	       ICL_TYPE_LONG, (afs_int32) off, ICL_TYPE_LONG, (afs_int32) len,
@@ -615,7 +624,12 @@ int afs_putapage(struct vnode *vp, struct page *pages,
 #else
 		 u_int *offp,
 #endif
-		 u_int *lenp, int flags, struct AFS_UCRED *credp)
+#if    defined(AFS_SUN58_ENV)
+                 size_t *lenp,
+#else
+                 u_int *lenp,
+#endif
+                 int flags, struct AFS_UCRED *credp)
 {
     struct buf *tbuf;
     struct vcache *avc = (struct vcache *)vp;
