@@ -13,7 +13,11 @@
  * afs_LocalHero
  */
 
-#include "../afs/param.h"	/* Should be always first */
+#include <afsconfig.h>
+#include "../afs/param.h"
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_vnop_create.c,v 1.1.1.6 2001/07/14 22:19:54 hartmans Exp $");
+
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
 #include "../afs/afs_stats.h" /* statistics */
@@ -177,6 +181,9 @@ tagain:
 		if ((amode & VWRITE) || len != 0xffffffff) 
 #endif
 		  {
+		    /* needed for write access check */
+		    tvc->parentVnode = adp->fid.Fid.Vnode;
+		    tvc->parentUnique = adp->fid.Fid.Unique;
 		    /* need write mode for these guys */
 		    if (!afs_AccessOK(tvc, PRSFS_WRITE, &treq, CHECK_MODE_BITS)) {
 			afs_PutVCache(tvc, READ_LOCK);
@@ -287,7 +294,7 @@ tagain:
       (afs_Analyze(tc, code, &adp->fid, &treq,
 		   AFS_STATS_FS_RPCIDX_CREATEFILE, SHARED_LOCK, (struct cell *)0));
 
-#ifdef	AFS_OSF_ENV
+#if defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV)
     if (code == EEXIST && aexcl == NONEXCL) {
 	/* This lookup was handled in the common vn_open code in the
 	   vnode layer */
