@@ -12,7 +12,11 @@
  *
  */
 
-#include "../afs/param.h"	/* Should be always first */
+#include <afsconfig.h>
+#include "../afs/param.h"
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_vnop_flock.c,v 1.1.1.7 2001/07/14 22:19:55 hartmans Exp $");
+
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
 #include "../afs/afs_stats.h" /* statistics */
@@ -23,7 +27,7 @@
 #if	defined(AFS_HPUX102_ENV)
 #define AFS_FLOCK	k_flock
 #else
-#if	defined(AFS_SUN56_ENV)
+#if	defined(AFS_SUN56_ENV) || defined(AFS_LINUX24_ENV)
 #define AFS_FLOCK       flock64
 #else
 #define AFS_FLOCK	flock
@@ -534,11 +538,16 @@ struct AFS_UCRED *acred; {
 	   with it in.  However, they fail in race conditions.  The question is
 	   what to do for people who don't have source to their application;
 	   this way at least, they can get work done */
+#ifdef AFS_LINUX24_ENV
+       if (af->l_len == OFFSET_MAX)
+	   af->l_len = 0;      /* since some systems indicate it as EOF */
+#else
 	if (af->l_len == 0x7fffffff)
 	    af->l_len = 0;	/* since some systems indicate it as EOF */
 #ifdef AFS_LINUX_64BIT_KERNEL
 	if (af->l_len == LONG_MAX)
 	    af->l_len = 0;      /* since some systems indicate it as EOF */
+#endif
 #endif
 	/* next line makes byte range locks always succeed,
 	   even when they should block */
