@@ -19,7 +19,11 @@
  * 
  */
 
-#include "../afs/param.h"	/* Should be always first */
+#include <afsconfig.h>
+#include "../afs/param.h"
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_vnop_readdir.c,v 1.1.1.7 2001/07/14 22:19:57 hartmans Exp $");
+
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
 #include "../afs/afs_stats.h" /* statistics */
@@ -59,8 +63,12 @@ extern struct DirEntry * afs_dir_GetBlob();
 #if defined(AFS_SGI62_ENV) || defined(AFS_SUN57_64BIT_ENV)
 int BlobScan(ino64_t *afile, afs_int32 ablob)
 #else
+#ifdef AFS_LINUX_64BIT_KERNEL
+int BlobScan(long *afile, afs_int32 ablob)
+#else
 int BlobScan(afs_int32 *afile, afs_int32 ablob)
 #endif
+#endif
 {
     register afs_int32 relativeBlob;
     afs_int32 pageBlob;
@@ -132,6 +140,12 @@ struct irix5_min_dirent {     /* miniature dirent structure */
 #else
 struct min_direct {	/* miniature direct structure */
 			/* If struct direct changes, this must too */
+#ifdef AFS_DARWIN_ENV
+    afs_uint32  d_fileno;
+    u_short     d_reclen;
+    u_char      d_type;
+    u_char      d_namlen;
+#else   
 #ifdef	AFS_SUN5_ENV
     afs_uint32	d_fileno;
     afs_int32	d_off;
@@ -147,6 +161,7 @@ struct min_direct {	/* miniature direct structure */
     u_short	d_reclen;
     u_short	d_namlen;
 #endif
+#endif
 };
 #endif /* AFS_SGI_ENV */
 
@@ -333,6 +348,9 @@ int			off;
 #if defined(AFS_SUN_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_SGI_ENV)
     sdirEntry.d_off = off;
 #endif
+#if defined(AFS_DARWIN_ENV)
+    sdirEntry.d_type=DT_UNKNOWN;
+#endif
 
 #if defined(AFS_SGI_ENV)
     AFS_UIOMOVE(&sdirEntry, DIRENTBASESIZE, UIO_READ, auio, code);
@@ -405,7 +423,7 @@ void afs_bulkstat_send( avc, req )
  * It has to do with 'offset' (seek locations).
 */
 
-#if	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV) || defined(AFS_OSF_ENV)
+#if	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV) || defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV)
 afs_readdir(OSI_VC_ARG(avc), auio, acred, eofp)
     int *eofp;
 #else
@@ -462,7 +480,7 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 #endif /* AFS_SGI61_ENV */
 #endif /* defined(AFS_SGI53_ENV) */
 
-#if	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV) || defined(AFS_OSF_ENV)
+#if	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV) || defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV)
     /* Not really used by the callee so we ignore it for now */
     if (eofp) *eofp = 0;
 #endif
@@ -637,11 +655,7 @@ tagain:
 		}
 #else /* AFS_HPUX_ENV */
 		code = afs_readdir_move(ode, avc, auio, o_slen,
-#ifdef defined(AFS_SUN5_ENV)
-		                        len, origOffset);
-#else
 					auio->afsio_resid, origOffset);
-#endif
 #endif /* AFS_HPUX_ENV */
 		/* this next line used to be AFSVFS40 or AIX 3.1, but is
 		 * really generic */
