@@ -10,7 +10,11 @@
 /*
  * Implements:
  */
-#include "../afs/param.h"	/* Should be always first */
+#include <afsconfig.h>
+#include "../afs/param.h"
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/afs_conn.c,v 1.1.1.6 2001/07/14 22:19:20 hartmans Exp $");
+
 #include "../afs/stds.h"
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 
