@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#include <afs/param.h>				/* for machine/host info */
+#include <afsconfig.h>
+#include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/bu_utils/fms.c,v 1.1.1.4 2001/07/14 22:20:46 hartmans Exp $");
+
 #undef	IN
 #include <stdio.h>
 #include <errno.h>
