@@ -7,6 +7,11 @@
  * This routine generates an odd-parity table for use in key generation.
  */
 
+#include <afsconfig.h>
+#include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/des/make_odd.c,v 1.1.1.3 2001/07/14 22:21:34 hartmans Exp $");
+
 #include <mit-cpyright.h>
 #include <stdio.h>
 
