@@ -11,6 +11,11 @@
  * object_test: A test of the gator object operations.
  *--------------------------------------------------------------------------------*/
 
+#include <afsconfig.h>
+#include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/gtx/object_test.c,v 1.1.1.4 2001/07/14 22:22:03 hartmans Exp $");
+
 #include "gtxscreenobj.h"     /*Gator screen object interface*/
 #include "gtxtextobj.h"       /*Gator text object interface*/
 #include "gtxlightobj.h"      /*Gator light object interface*/
