@@ -12,7 +12,11 @@
    make small changes as well as subroutines to permit specialized programs to
    update the database, change the server passwords, etc. */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/kauth/admin_tools.c,v 1.1.1.7 2001/07/14 22:22:07 hartmans Exp $");
+
 #include <afs/stds.h>
 #include <afs/debug.h>
 #include <ctype.h>
@@ -768,7 +772,11 @@ int SetPassword (
     if (as->parms[3].items) 
       sscanf (as->parms[3].items->data, "%d", &kvno);
 
+#ifdef AFS_S390_LINUX20_ENV
+    code = ubik_Call (KAM_SetPassword, conn, 0, name, instance, kvno, 0, key);
+#else
     code = ubik_Call (KAM_SetPassword, conn, 0, name, instance, kvno, key);
+#endif
     if (code) com_err (whoami, code,
 		       "so can't set password for %s.%s", name, instance);
     return code;
