@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/kauth/kadatabase.c,v 1.1.1.4 2001/07/14 22:22:10 hartmans Exp $");
+
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -384,9 +388,6 @@ afs_int32 ka_NewKey (tt, tentryaddr, tentry, key)
   afs_int32 newtotalkeyentries = 0, oldtotalkeyentries = 0, keyentries;
   int   foundcurrentkey = 0, addednewkey = 0, modified;
 
-#if !SPECIAL
-    if ((ntohl(tentry->flags) & KAFSPECIAL) == 0) return KANOTSPECIAL;
-#endif
     es_Report ("Newkey for %s.%s\n", tentry->userID.name, tentry->userID.instance);
 
     newkeyver = ntohl(tentry->key_version) + 1;
@@ -546,10 +547,6 @@ afs_int32 ka_DelKey (tt, tentryaddr, tentry)
     afs_int32 prevptr = 0;
     Date  now = time(0);
 
-#if !SPECIAL
-    if ((ntohl(tentry->flags) & KAFSPECIAL) == 0) return KANOTSPECIAL;
-#endif
-
     es_Report ("DelKey for %s.%s\n", tentry->userID.name, tentry->userID.instance);
 
     /* An entry may have more than one oldkeys blocks. The entry
@@ -717,9 +714,6 @@ afs_int32 ka_LookupKvno (tt, name, inst, kvno, key)
     code = FindBlock (tt, name, inst, &to, &tentry);
     if (code) return code;
     if (to == 0) return KANOENT;
-#if !SPECIAL
-    if ((ntohl(tentry.flags) & KAFSPECIAL) == 0) return KANOTSPECIAL; 
-#endif
 
     /* first check the current key */
     if (tentry.key_version == htonl(kvno)) {
@@ -783,9 +777,6 @@ afs_int32 ka_LookupKey (tt, name, inst, kvno, key)
     code = FindBlock (tt, name, inst, &to, &tentry);
     if (code) return code;
     if (to == 0) return KANOENT;
-#if !SPECIAL
-    if ((ntohl(tentry.flags) & KAFSPECIAL) == 0) return KANOTSPECIAL;
-#endif
     bcopy (&tentry.key, key, sizeof(*key));
     *kvno = ntohl(tentry.key_version);
     ka_Encache (name, inst, *kvno, key, NEVERDATE);
