@@ -7,23 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-/*
- * Revision 2.4  1990/10/01  10:01:37
- * Include <netinet/in.h> so ntohl is defined properly.
- *
- * Revision 2.3  90/09/28  16:18:23
- * Cleanups.
- * Move KeyIsZero here.
- * Add KeyCheckSum function.
- * 
- * Revision 2.2  90/09/19  08:31:04
- * Include afs/param.h.
- * 
- * Revision 2.1  90/08/29  08:37:41
- * Start with clean version to sync test and dev trees.
- * */
-
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/kauth/kautils.c,v 1.1.1.5 2001/07/14 22:22:13 hartmans Exp $");
+
 #include <afs/stds.h>
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -42,9 +30,6 @@
 #include "kauth.h"
 #include "kautils.h"
 
-#include "../permit_xprt.h"
-
-
 
 /* This should match the behavior of ParseLoginName on input so that the output
  * and input are compatible.  In names "." should show as \056 and in names and
@@ -184,12 +169,14 @@ void ka_timestr (
   afs_int32 tlen)
 {
     char tbuffer[32]; /* need at least 26 bytes */
+    time_t passtime; /* modern systems have 64 bit time */
 
     if (!time) strcpy (tstr, "no date");/* special case this */
     else if (time == NEVERDATE) strcpy(tstr, "never");
     else {
+	passtime = time;
 	strncpy(tstr,
-		afs_ctime((time_t *)&time, tbuffer, sizeof(tbuffer)), tlen);
+		afs_ctime(&passtime, tbuffer, sizeof(tbuffer)), tlen);
 	tstr[strlen(tstr)-1] = '\0';	/* punt the newline character */
     }
 }
