@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/kauth/rebuild.c,v 1.1.1.6 2001/07/14 22:22:17 hartmans Exp $");
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #ifdef AFS_NT40_ENV
@@ -176,7 +180,7 @@ PrintEntry(index, entry)
   printf("   Key Version = %d\n", entry->key_version);
 
   printf("   Key = ");
-  ka_PrintBytes (&entry->key, sizeof(entry->key));
+  ka_PrintBytes ((char *)&entry->key, sizeof(entry->key));
   printf("\n");
 
   /* What about asServer structs and such and misc_ath_bytes */
@@ -229,8 +233,9 @@ RebuildEntry(entryp)
 
   fprintf(out, "create    -name %s", EntryName(entryp));
 
-  ka_ConvertBytes (key, sizeof(key), &entryp->key, sizeof(entryp->key));
-  fprintf(out, " -initial_password foo\n", key);
+  ka_ConvertBytes (key, sizeof(key), (char *)&entryp->key, 
+		   sizeof(entryp->key));
+  fprintf(out, " -initial_password foo\n");
 
   strcpy(flags,"");
   if (entryp->flags & KAFADMIN)  strcat(flags, "+ADMIN");
