@@ -7,6 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
+#include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/libadmin/kas/afs_kasAdmin.c,v 1.1.1.5 2001/07/14 22:22:32 hartmans Exp $");
+
 #include <stdio.h>
 #include <afs/stds.h>
 #include "afs_kasAdmin.h"
@@ -660,6 +665,7 @@ static int GetPrincipalLockStatus(
     afs_status_t tst = 0;
     unsigned int locked;
     int count=0;
+    int once = 0;
  
     /*
      * Validate input arguments and make rpc.
@@ -709,8 +715,9 @@ static int GetPrincipalLockStatus(
 			    &locked, 0, 0, 0, 0);
 	if (tst == 0) {
 	    if (locked) {
-		if (locked < *lockedUntil) {
+		if ((locked < *lockedUntil) || !once) {
 		    *lockedUntil = locked;
+		    once++;
 		}
 	    }
 	}
@@ -723,7 +730,7 @@ static int GetPrincipalLockStatus(
     if ((tst == 0) && (locked == 0)) {
 	*lockedUntil = 0;
     }
-    if (tst == 0) {
+    if ((tst == 0) || (tst == UNOSERVERS)) {
 	rc = 1;
     }
 
@@ -877,7 +884,6 @@ static int GetPrincipalFromCache(
     int rc = 0;
     afs_status_t tst = 0;
     principal_get_p prin = (principal_get_p) rpc_specific;
-    kas_identity_p who = (kas_identity_p) dest;
 
     memcpy(dest, &prin->principal[slot], sizeof(kas_identity_t));
     rc = 1;
@@ -1007,7 +1013,6 @@ int ADMINAPI kas_PrincipalGetNext(
     int rc = 0;
     afs_status_t tst = 0;
     afs_admin_iterator_p iter = (afs_admin_iterator_p) iterationId;
-    int locked_iter = 0;
  
     /*
      * Validate arguments
@@ -1142,6 +1147,9 @@ int ADMINAPI kas_PrincipalKeySet(
     if (tst) {
 	goto fail_kas_PrincipalKeySet;
     }
+
+    /* If we failed to fail we must have succeeded */
+    rc = 1;
  
 fail_kas_PrincipalKeySet:
 
@@ -1283,7 +1291,7 @@ int ADMINAPI kas_PrincipalUnlock(
 	}
     } while (tst != UNOSERVERS);
 
-    if (tst == 0) {
+    if ((tst == 0) || (tst == UNOSERVERS)){
 	rc = 1;
     }
 
@@ -1407,7 +1415,6 @@ int ADMINAPI kas_PrincipalFieldsSet(
     int was_spare;
     char spare_bytes[4] = {0,0,0,0};
     int somethings_changing = 0;
-    int have_got_current_flag = 0;
 
     /*
      * Validate input arguments.
