@@ -7,140 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifndef	lint
-#endif /* lint */
-/*
- * Revision 1.2  1993/04/11  17:35:40
- * define NOSWAP option on sgi
- *
- * Revision 1.1  1992/09/21  16:35:59
- *
- * Revision 2.6  91/08/13  12:28:10
- * Expect HP-UX to need large BOGUS drift comp value.
- * 
- * Revision 2.5  90/12/03  14:19:34
- * Add some miscellaneous debugging and checking stmts.
- * In query_mode, peer->sock needed better array bounds checking.
- * 
- * Revision 2.4  90/10/08  15:44:45
- * Add -f switch that prevents forking.
- * Also fix syslog message to use %s instead of %d!
- * 
- * Revision 2.3  90/09/27  16:57:07
- * Bring afs.dev in sync with afs.test
- * 
- * Revision 2.2  90/09/19  16:32:05
- * Add parameter to set dosynctodr kernel variable.  Also subroutinize the
- *   kernel setting code to make this easy.
- * Call MeasurePrecision to get real precision.
- * On HP set daemon to run at real time priority.
- * Output floating point version of timestamps in dump_pkt.
- * Also on HP ignore zero length packets.
- * Call syslog w/ correct parameters.
- * 
- * Revision 2.1  90/08/07  19:23:11
- * Start with clean version to sync test and dev trees.
- * 
- * Revision 1.22  90/06/13  20:09:36
- * rs_aix31
- * 
- * Revision 1.21  90/05/24  16:17:24
- * Moved timeout interval bias into ntp_adjust.
- * Changed bogus drift compensation from 2.0 to 10.0.
- * 
- * Revision 1.20  90/05/21  13:48:11
- * Various changed for AIX:
- * 1. #define BSD_REMAP_SIGNAL_TO_SIGVEC so signal works right.
- * 2. skew the CLOCK_ADJ so it doesn't happen same time every second.
- * 3. Up the bogus drift_comp value from 1.0 to 2.0.
- * 
- * Revision 1.19  89/12/22  20:32:11
- * hp/ux specific (initial port to it); Added <afs/param.h> and special include files for HPUX and misc other changes
- * 
- * Revision 1.18  89/12/11  14:25:51
- * Added code to support AIX 2.2.1.
- * 
- * Revision 1.17  89/05/24  12:26:23
- * Latest May 18, Version 4.3 release from UMD.
- * 
- * Revision 3.4.1.9  89/05/18  18:30:17
- * Changes in ntpd.c for reference clock support.  Also, a few diddles to
- * accomodate the NeXT computer system that has a slightly different nlist.h
- * 
- * Revision 3.4.1.8  89/05/03  15:16:17
- * Add code to save the value of the drift compensation register to a file every
- * hour.  Add additional configuration file directives which can specify the same
- * information as on the command line.
- * 
- * Revision 3.4.1.7  89/04/10  15:58:45
- * Add -l option to enable logging of clock adjust messages.
- * 
- * Revision 3.4.1.6  89/04/07  19:09:04
- * Added NOSWAP code for Ultrix systems to lock NTP process in memory.  Deleted
- * unused variable in ntpd.c
- * 
- * Revision 3.4.1.5  89/03/31  16:37:49
- * Add support for "trusting" directive in NTP configuration file.  It allows 
- * you to specify at run time if non-configured peers will be synced to.
- * 
- * Revision 3.4.1.4  89/03/29  12:30:46
- * peer->mode has been renamed peer->hmode.  Drop PEER_FL_SYNC since the
- * PEER_FL_CONFIG flag means much the same thing.
- * 
- * Revision 3.4.1.3  89/03/22  18:29:41
- * patch3: Use new RCS headers.
- * 
- * Revision 3.4.1.2  89/03/22  18:03:17
- * The peer->refid field was being htonl()'ed when it was already in network
- * byte order.
- * 
- * Revision 3.4.1.1  89/03/20  00:12:10
- * patch1: Diddle syslog messages a bit.  Handle case of udp/ntp not being
- * patch1: defined in /etc/services.  Compute default value for tickadj if
- * patch1: the change-kernel-tickadj flag is set, but no tickadj directive
- * patch1: is present in the configuration file.
- * 
- * Revision 3.4  89/03/17  18:37:11
- * Latest test release.
- * 
- * Revision 3.3.1.1  89/03/17  18:26:32
- * 1
- * 
- * Revision 3.3  89/03/15  14:19:56
- * New baseline for next release.
- * 
- * Revision 3.2.1.2  89/03/15  13:59:50
- * Initialize random number generator.  The ntpdc query_mode() routine has been
- * revised to send more peers per packet, a count of the total number of peers
- * which will be transmited, the number of packets to be transmitted, and a 
- * sequence number for each packet.  There is a new version number for the
- * ntpdc query packets, which is now symbolically defined in ntp.h
- * 
- * Revision 3.2.1.1  89/03/10  12:27:41
- * Removed reference to HUGE, and replaced it by a suitable large number.  Added
- * some #ifdef DEBUG .. #endif around some debug code that was missing.  Display
- * patchlevel along with version.
- * 
- * Revision 3.2  89/03/07  18:26:30
- * New version of the UNIX NTP daemon based on the 6 March 1989 draft of the
- * new NTP protcol spec.  A bunch of cosmetic changes.  The peer list is
- * now doublely linked, and a subroutine (enqueue()) replaces the ENQUEUE
- * macro used previously.
- * 
- * Revision 3.1.1.1  89/02/15  08:58:46
- * Bugfixes to released version.
- * 
- * 
- * Revision 3.1  89/01/30  14:43:14
- * Second UNIX NTP test release.
- * 
- * Revision 3.0  88/12/12  15:56:38
- * Test release of new UNIX NTP software.  This version should conform to the
- * revised NTP protocol specification.
- * 
- */
-
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/ntp/ntpd.c,v 1.1.1.4 2001/07/14 22:23:06 hartmans Exp $");
+
 #if defined(AFS_SGI_ENV)
 #define NOSWAP 1
 #endif
@@ -413,12 +284,12 @@ main(argc, argv)
 #endif	/* DEBUG */
 		setlogmask(LOG_UPTO(LOG_INFO));
 
-	syslog(LOG_NOTICE, "%s version $Revision: 1.1.1.2 $", prog_name);
+	syslog(LOG_NOTICE, "%s version $Revision: 1.1.1.4 $", prog_name);
 	syslog(LOG_NOTICE, "patchlevel %d", PATCHLEVEL);
 
 #ifdef	DEBUG
 	if (debug)
-		printf("%s version $Revision: 1.1.1.2 $ patchlevel %d\n",
+		printf("%s version $Revision: 1.1.1.4 $ patchlevel %d\n",
 		       prog_name, PATCHLEVEL);
 #endif
 #if defined(AFS_AIX_ENV)
