@@ -7,9 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifndef lint
-#endif
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/ptserver/pts.c,v 1.1.1.6 2001/07/14 22:23:18 hartmans Exp $");
+
 #include <stdio.h>
 #include <string.h>
 #ifdef	AFS_AIX32_ENV
@@ -78,13 +80,15 @@ int GetGlobals (as)
     return code;
 }
 
-void CleanUp (as)
+int CleanUp (as)
   register struct cmd_syndesc *as;
 {
     if (!strcmp(as->name,"help")) return;
     /* Need to shutdown the ubik_client & other connections */
     pr_End();
     rx_Finalize();
+
+    return 0;
 }
 
 CreateGroup (as)
@@ -123,8 +127,11 @@ CreateGroup (as)
 	if (code) {
 	    if (owner || id) 
 		com_err (whoami, code,
-			 "; unable to create group %s with id %d owned by '%s' %s",
-			 namei->data, id, owner, (force?"(ignored)":""));
+			 "; unable to create group %s with id %d%s%s%s%s",
+			 namei->data, id, owner ? " owned by '" : "",
+			 owner ? owner : "",
+			 owner ? "'" : "",
+			 (force ? " (ignored)" : ""));
 	    else com_err (whoami, code,
 			 "; unable to create group %s %s", namei->data, (force?"(ignored)":""));
 	    if (!force)
