@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/ptserver/ptutils.c,v 1.1.1.7 2001/07/14 22:23:21 hartmans Exp $");
+
 #include <afs/stds.h>
 #include <sys/types.h>
 #include <stdio.h>
@@ -21,6 +25,7 @@
 #include <ubik.h>
 #include <rx/xdr.h>
 #include <afs/com_err.h>
+#include <afs/cellconfig.h>
 #include "ptserver.h"
 #include "pterror.h"
 #include <stdlib.h>
