@@ -12,6 +12,14 @@
 
 #ifdef	KERNEL
 #include "../afs/param.h"
+#else
+#include <afs/param.h>
+#endif
+#include <afsconfig.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/rx/rx_clock.c,v 1.1.1.5 2001/07/11 03:10:48 hartmans Exp $");
+
+#ifdef KERNEL
 #ifndef UKERNEL
 #include "../rx/rx_clock.h"
 #include "../h/types.h"
@@ -22,7 +30,6 @@
 #include "../rx/rx_clock.h"
 #endif /* !UKERNEL */
 #else /* KERNEL */
-#include <afs/param.h>
 #include <sys/time.h>
 #include <stdio.h>
 #include <errno.h>
@@ -46,13 +53,13 @@ struct clock clock_now;		/* The last elapsed time ready by clock_GetTimer */
 int clock_haveCurrentTime;
 
 int clock_nUpdates;		/* The actual number of clock updates */
+static int clockInitialized = 0;
 
 /* Initialize the clock */
 void clock_Init(void) {
-    static initialized = 0;
     struct itimerval itimer, otimer;
 
-    if (!initialized) {
+    if (!clockInitialized) {
 	itimer.it_value.tv_sec = STARTVALUE;
 	itimer.it_value.tv_usec = 0;
 	itimer.it_interval.tv_sec = 0;
@@ -64,12 +71,22 @@ void clock_Init(void) {
 	    fflush (stderr);
 	    exit(1);
 	}
-	initialized = 1;
+	clockInitialized = 1;
     }
 
     clock_UpdateTime();
 }
 
+#ifndef KERNEL
+/* Make clock uninitialized. */
+int
+clock_UnInit()
+{
+    clockInitialized = 0;
+    return 0;
+} 
+#endif 
+
 /* Compute the current time.  The timer gets the current total elapsed time since startup, expressed in seconds and microseconds.  This call is almost 200 usec on an APC RT */
 void clock_UpdateTime()
 {
