@@ -15,10 +15,14 @@
  * rx_pthread.c is used for the thread safe RX package.
  */
 
-# include <afs/param.h>
-# include <sys/types.h>
-# include <errno.h>
-# include <signal.h>
+#include <afsconfig.h>
+#include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/rx/rx_pthread.c,v 1.1.1.6 2001/07/14 22:23:34 hartmans Exp $");
+
+#include <sys/types.h>
+#include <errno.h>
+#include <signal.h>
 #ifndef AFS_NT40_ENV
 # include <sys/socket.h>
 # include <sys/file.h>
@@ -28,11 +32,11 @@
 # include <sys/ioctl.h>
 # include <sys/time.h>
 #endif
-# include <sys/stat.h>
-# include <rx.h>
-# include <rx_globals.h>
-# include <assert.h>
-# include <rx/rx_pthread.h>
+#include <sys/stat.h>
+#include <rx.h>
+#include <rx_globals.h>
+#include <assert.h>
+#include <rx/rx_pthread.h>
 
 /*
  * Number of times the event handling thread was signalled because a new
@@ -69,7 +73,7 @@ struct clock rxi_clockNow;
 /*
  * Delay the current thread the specified number of seconds.
  */
-rxi_Delay(sec)
+void rxi_Delay(sec)
     int sec;
 {
     sleep(sec);
