@@ -15,14 +15,13 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifndef lint
-static char sccsid[] = "@(#)setup.c	5.25 (Berkeley) 2/1/90";
-#endif /* not lint */
+#include <afsconfig.h>
+#include <afs/param.h>
 
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/vfsck/setup.c,v 1.1.1.3 2001/07/14 22:24:43 hartmans Exp $");
 
 #include <stdio.h>
 #define VICE
-#include <afs/param.h>
 
 #if	defined(AFS_SUN_ENV) || defined(AFS_OSF_ENV)
 #define AFS_NEWCG_ENV
