@@ -7,8 +7,6 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifndef lint
-#endif
 /*
 
 	System:		VICE-TWO
@@ -19,7 +17,11 @@
 
 #define ITC	/* Required by inode.h */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/vol/listinodes.c,v 1.1.1.7 2001/07/14 22:24:55 hartmans Exp $");
+
 #ifndef AFS_NAMEI_ENV
 #ifdef AFS_LINUX20_ENV
 /* ListViceInodes
@@ -72,7 +74,7 @@ int *forcep, forceR;
 #ifdef	  AFS_SUN5_ENV
 #include <sys/fs/ufs_inode.h>
 #else
-#if defined(AFS_DARWIN_ENV)
+#if !defined(AFS_DARWIN_ENV)
 #include <ufs/inode.h>
 #endif
 #endif
