@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/volser/volmain.c,v 1.1.1.7 2001/07/14 22:25:09 hartmans Exp $");
+
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
 #include <time.h>
@@ -287,13 +291,18 @@ char **argv; {
 	else {
 	    printf("volserver: unrecognized flag '%s'\n", argv[code]);
 usage:
+#ifndef AFS_NT40_ENV
 	    printf("Usage: volserver [-log] [-p <number of processes>] "
 		   "[-udpsize <size of socket buffer in bytes>] "
-#ifndef AFS_NT40_ENV
 		   "[-syslog[=FACILITY]] "
-#endif
-		   /* "[-enable_peer_stats] [-enable_process_stats] " */
+		   "[-enable_peer_stats] [-enable_process_stats] "
 		   "[-help]\n");
+#else
+	    printf("Usage: volserver [-log] [-p <number of processes>] "
+		   "[-udpsize <size of socket buffer in bytes>] "
+		   "[-enable_peer_stats] [-enable_process_stats] "
+		   "[-help]\n");
+#endif
 	    VS_EXIT(1);
 	}
     }
